@@ -16,7 +16,7 @@ use SQL::Translator::Diff;
 no warnings;
 use Data::Dumper;
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 has description => 'MySQL migration tool';
 has usage       => sub { shift->extract_usage };
@@ -379,14 +379,7 @@ sub prepare {
 			);
 			die "Cant create MySQL upgrade: $error" if $error;
 
-			my $diff = SQL::Translator::Diff->new({
-				output_db               => 'MySQL',
-				source_schema           => $target_schema,
-				target_schema           => $source_schema,
-				ignore_index_names      => 1,
-				ignore_constraint_names => 1,
-				caseopt                 => 1,
-			})->compute_differences->produce_diff_sql;
+			my $diff = $self->_diff($source_schema, $target_schema);
 
 			my $error = $self->save_migration(
 				path => "$paths->{db_downgrade}/$new_version-$last_version/001_auto.sql",
@@ -459,6 +452,9 @@ sub _diff {
 		for my $field (@{$diff->{table_diff_hash}->{$table}->{fields_to_create}}) {
 			$h->{$table}->{$field->name} = [grep {$_->order == $field->{order} - 1} $field->table->get_fields]->[0]->{name};
 		}
+		for my $field (@{$diff->{table_diff_hash}->{$table}->{fields_to_drop}}) {
+			$h->{$table}->{$field->name} = [grep {$_->order == $field->{order} - 1} $field->table->get_fields]->[0]->{name};
+		}
 	}
 	$diff = $diff->produce_diff_sql;
 
@@ -468,7 +464,11 @@ sub _diff {
 			my ($t, $a) = $s =~ /ALTER TABLE ([^\s]+) ([^;]+)/;
 
 			for ($a =~ /ADD COLUMN ([^\s]+) /g) {
-				$s =~ s/ADD COLUMN $_ (.*)([\,\;])/ADD COLUMN $_ $1 AFTER $h->{$t}->{$_}$2/g;
+				$s =~ s/ADD COLUMN $_ (.*)([\,\;])/ADD COLUMN `$_` $1 AFTER `$h->{$t}->{$_}`$2/g;
+			}
+
+			for ($a =~ /DROP COLUMN ([^\s,;]+)/g) {
+				$s =~ s/DROP COLUMN $_/DROP COLUMN `$_`/g;
 			}
 		}
 
@@ -617,7 +617,7 @@ Mojolicious::Command::migration — MySQL migration tool for Mojolicious
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
  
